@@ -4,9 +4,10 @@ use pyo3::types::{PyBytes, PyDict};
 use pythonize::{depythonize, pythonize};
 use std::str::FromStr;
 use std::sync::Mutex;
-use vl_convert_rs::converter::{VgOpts, VlOpts};
+use vl_convert_rs::converter::{FormatLocale, TimeFormatLocale, VgOpts, VlOpts};
 use vl_convert_rs::html::bundle_vega_snippet;
 use vl_convert_rs::module_loader::import_map::VlVersion;
+use vl_convert_rs::module_loader::{FORMATE_LOCALE_MAP, TIME_FORMATE_LOCALE_MAP};
 use vl_convert_rs::serde_json;
 use vl_convert_rs::text::register_font_directory as register_font_directory_rs;
 use vl_convert_rs::VlConverter as VlConverterRs;
@@ -64,6 +65,8 @@ fn vegalite_to_vega(
             theme,
             show_warnings: show_warnings.unwrap_or(false),
             allowed_base_urls: None,
+            format_locale: None,
+            time_format_locale: None,
         },
     )) {
         Ok(vega_spec) => vega_spec,
@@ -85,20 +88,34 @@ fn vegalite_to_vega(
 ///     vg_spec (str | dict): Vega JSON specification string or dict
 ///     allowed_base_urls (list of str): List of allowed base URLs for external
 ///                                      data requests. Default allows any base URL
+///     format_locale (str | dict): d3-format locale name or dictionary
+///     time_format_locale (str | dict): d3-time-format locale name or dictionary
 /// Returns:
 ///     str: SVG image string
 #[pyfunction]
-#[pyo3(text_signature = "(vg_spec, allowed_base_urls)")]
-fn vega_to_svg(vg_spec: PyObject, allowed_base_urls: Option<Vec<String>>) -> PyResult<String> {
+#[pyo3(text_signature = "(vg_spec, allowed_base_urls, format_locale, time_format_locale)")]
+fn vega_to_svg(
+    vg_spec: PyObject,
+    allowed_base_urls: Option<Vec<String>>,
+    format_locale: Option<PyObject>,
+    time_format_locale: Option<PyObject>,
+) -> PyResult<String> {
     let vg_spec = parse_json_spec(vg_spec)?;
+    let format_locale = parse_option_format_locale(format_locale)?;
+    let time_format_locale = parse_option_time_format_locale(time_format_locale)?;
 
     let mut converter = VL_CONVERTER
         .lock()
         .expect("Failed to acquire lock on Vega-Lite converter");
 
-    let svg = match PYTHON_RUNTIME
-        .block_on(converter.vega_to_svg(vg_spec, VgOpts { allowed_base_urls }))
-    {
+    let svg = match PYTHON_RUNTIME.block_on(converter.vega_to_svg(
+        vg_spec,
+        VgOpts {
+            allowed_base_urls,
+            format_locale,
+            time_format_locale,
+        },
+    )) {
         Ok(vega_spec) => vega_spec,
         Err(err) => {
             return Err(PyValueError::new_err(format!(
@@ -116,23 +133,34 @@ fn vega_to_svg(vg_spec: PyObject, allowed_base_urls: Option<Vec<String>>) -> PyR
 ///     vg_spec (str | dict): Vega JSON specification string or dict
 ///     allowed_base_urls (list of str): List of allowed base URLs for external
 ///                                      data requests. Default allows any base URL
+///     format_locale (str | dict): d3-format locale name or dictionary
+///     time_format_locale (str | dict): d3-time-format locale name or dictionary
 /// Returns:
 ///     dict: scenegraph
 #[pyfunction]
-#[pyo3(text_signature = "(vg_spec, allowed_base_urls)")]
+#[pyo3(text_signature = "(vg_spec, allowed_base_urls, format_locale, time_format_locale)")]
 fn vega_to_scenegraph(
     vg_spec: PyObject,
     allowed_base_urls: Option<Vec<String>>,
+    format_locale: Option<PyObject>,
+    time_format_locale: Option<PyObject>,
 ) -> PyResult<PyObject> {
     let vg_spec = parse_json_spec(vg_spec)?;
+    let format_locale = parse_option_format_locale(format_locale)?;
+    let time_format_locale = parse_option_time_format_locale(time_format_locale)?;
 
     let mut converter = VL_CONVERTER
         .lock()
         .expect("Failed to acquire lock on Vega-Lite converter");
 
-    let sg = match PYTHON_RUNTIME
-        .block_on(converter.vega_to_scenegraph(vg_spec, VgOpts { allowed_base_urls }))
-    {
+    let sg = match PYTHON_RUNTIME.block_on(converter.vega_to_scenegraph(
+        vg_spec,
+        VgOpts {
+            allowed_base_urls,
+            format_locale,
+            time_format_locale,
+        },
+    )) {
         Ok(vega_spec) => vega_spec,
         Err(err) => {
             return Err(PyValueError::new_err(format!(
@@ -158,10 +186,15 @@ fn vega_to_scenegraph(
 ///     show_warnings (bool | None): Whether to print Vega-Lite compilation warnings (default false)
 ///     allowed_base_urls (list of str): List of allowed base URLs for external
 ///                                      data requests. Default allows any base URL
+///     format_locale (str | dict): d3-format locale name or dictionary
+///     time_format_locale (str | dict): d3-time-format locale name or dictionary
 /// Returns:
 ///     str: SVG image string
+#[allow(clippy::too_many_arguments)]
 #[pyfunction]
-#[pyo3(text_signature = "(vl_spec, vl_version, config, theme, show_warnings, allowed_base_urls)")]
+#[pyo3(
+    text_signature = "(vl_spec, vl_version, config, theme, show_warnings, allowed_base_urls, format_locale, time_format_locale)"
+)]
 fn vegalite_to_svg(
     vl_spec: PyObject,
     vl_version: Option<&str>,
@@ -169,9 +202,13 @@ fn vegalite_to_svg(
     theme: Option<String>,
     show_warnings: Option<bool>,
     allowed_base_urls: Option<Vec<String>>,
+    format_locale: Option<PyObject>,
+    time_format_locale: Option<PyObject>,
 ) -> PyResult<String> {
     let vl_spec = parse_json_spec(vl_spec)?;
     let config = config.and_then(|c| parse_json_spec(c).ok());
+    let format_locale = parse_option_format_locale(format_locale)?;
+    let time_format_locale = parse_option_time_format_locale(time_format_locale)?;
 
     let vl_version = if let Some(vl_version) = vl_version {
         VlVersion::from_str(vl_version)?
@@ -191,6 +228,8 @@ fn vegalite_to_svg(
             theme,
             show_warnings: show_warnings.unwrap_or(false),
             allowed_base_urls,
+            format_locale,
+            time_format_locale,
         },
     )) {
         Ok(vega_spec) => vega_spec,
@@ -216,10 +255,15 @@ fn vegalite_to_svg(
 ///     show_warnings (bool | None): Whether to print Vega-Lite compilation warnings (default false)
 ///     allowed_base_urls (list of str): List of allowed base URLs for external
 ///                                      data requests. Default allows any base URL
+///     format_locale (str | dict): d3-format locale name or dictionary
+///     time_format_locale (str | dict): d3-time-format locale name or dictionary
 /// Returns:
 ///     str: SVG image string
+#[allow(clippy::too_many_arguments)]
 #[pyfunction]
-#[pyo3(text_signature = "(vl_spec, vl_version, config, theme, show_warnings, allowed_base_urls)")]
+#[pyo3(
+    text_signature = "(vl_spec, vl_version, config, theme, show_warnings, allowed_base_urls, format_locale, time_format_locale)"
+)]
 fn vegalite_to_scenegraph(
     vl_spec: PyObject,
     vl_version: Option<&str>,
@@ -227,9 +271,13 @@ fn vegalite_to_scenegraph(
     theme: Option<String>,
     show_warnings: Option<bool>,
     allowed_base_urls: Option<Vec<String>>,
+    format_locale: Option<PyObject>,
+    time_format_locale: Option<PyObject>,
 ) -> PyResult<PyObject> {
     let vl_spec = parse_json_spec(vl_spec)?;
     let config = config.and_then(|c| parse_json_spec(c).ok());
+    let format_locale = parse_option_format_locale(format_locale)?;
+    let time_format_locale = parse_option_time_format_locale(time_format_locale)?;
 
     let vl_version = if let Some(vl_version) = vl_version {
         VlVersion::from_str(vl_version)?
@@ -249,6 +297,8 @@ fn vegalite_to_scenegraph(
             theme,
             show_warnings: show_warnings.unwrap_or(false),
             allowed_base_urls,
+            format_locale,
+            time_format_locale,
         },
     )) {
         Ok(vega_spec) => vega_spec,
@@ -272,17 +322,25 @@ fn vegalite_to_scenegraph(
 ///     ppi (float): Pixels per inch (default 72)
 ///     allowed_base_urls (list of str): List of allowed base URLs for external
 ///                                      data requests. Default allows any base URL
+///     format_locale (str | dict): d3-format locale name or dictionary
+///     time_format_locale (str | dict): d3-time-format locale name or dictionary
 /// Returns:
 ///     bytes: PNG image data
 #[pyfunction]
-#[pyo3(text_signature = "(vg_spec, scale, ppi, allowed_base_urls)")]
+#[pyo3(
+    text_signature = "(vg_spec, scale, ppi, allowed_base_urls, format_locale, time_format_locale)"
+)]
 fn vega_to_png(
     vg_spec: PyObject,
     scale: Option<f32>,
     ppi: Option<f32>,
     allowed_base_urls: Option<Vec<String>>,
+    format_locale: Option<PyObject>,
+    time_format_locale: Option<PyObject>,
 ) -> PyResult<PyObject> {
     let vg_spec = parse_json_spec(vg_spec)?;
+    let format_locale = parse_option_format_locale(format_locale)?;
+    let time_format_locale = parse_option_time_format_locale(time_format_locale)?;
 
     let mut converter = VL_CONVERTER
         .lock()
@@ -290,7 +348,11 @@ fn vega_to_png(
 
     let png_data = match PYTHON_RUNTIME.block_on(converter.vega_to_png(
         vg_spec,
-        VgOpts { allowed_base_urls },
+        VgOpts {
+            allowed_base_urls,
+            format_locale,
+            time_format_locale,
+        },
         scale,
         ppi,
     )) {
@@ -322,11 +384,13 @@ fn vega_to_png(
 ///     show_warnings (bool | None): Whether to print Vega-Lite compilation warnings (default false)
 ///     allowed_base_urls (list of str): List of allowed base URLs for external
 ///                                      data requests. Default allows any base URL
+///     format_locale (str | dict): d3-format locale name or dictionary
+///     time_format_locale (str | dict): d3-time-format locale name or dictionary
 /// Returns:
 ///     bytes: PNG image data
 #[pyfunction]
 #[pyo3(
-    text_signature = "(vl_spec, vl_version, scale, ppi, config, theme, show_warnings, allowed_base_urls)"
+    text_signature = "(vl_spec, vl_version, scale, ppi, config, theme, show_warnings, allowed_base_urls, format_locale, time_format_locale)"
 )]
 #[allow(clippy::too_many_arguments)]
 fn vegalite_to_png(
@@ -338,6 +402,8 @@ fn vegalite_to_png(
     theme: Option<String>,
     show_warnings: Option<bool>,
     allowed_base_urls: Option<Vec<String>>,
+    format_locale: Option<PyObject>,
+    time_format_locale: Option<PyObject>,
 ) -> PyResult<PyObject> {
     let vl_version = if let Some(vl_version) = vl_version {
         VlVersion::from_str(vl_version)?
@@ -346,6 +412,8 @@ fn vegalite_to_png(
     };
     let vl_spec = parse_json_spec(vl_spec)?;
     let config = config.and_then(|c| parse_json_spec(c).ok());
+    let format_locale = parse_option_format_locale(format_locale)?;
+    let time_format_locale = parse_option_time_format_locale(time_format_locale)?;
 
     let mut converter = VL_CONVERTER
         .lock()
@@ -359,6 +427,8 @@ fn vegalite_to_png(
             theme,
             show_warnings: show_warnings.unwrap_or(false),
             allowed_base_urls,
+            format_locale,
+            time_format_locale,
         },
         scale,
         ppi,
@@ -385,17 +455,25 @@ fn vegalite_to_png(
 ///     quality (int): JPEG Quality between 0 (worst) and 100 (best). Default 90
 ///     allowed_base_urls (list of str): List of allowed base URLs for external
 ///                                      data requests. Default allows any base URL
+///     format_locale (str | dict): d3-format locale name or dictionary
+///     time_format_locale (str | dict): d3-time-format locale name or dictionary
 /// Returns:
 ///     bytes: JPEG image data
 #[pyfunction]
-#[pyo3(text_signature = "(vg_spec, scale, quality, allowed_base_urls)")]
+#[pyo3(
+    text_signature = "(vg_spec, scale, quality, allowed_base_urls, format_locale, time_format_locale)"
+)]
 fn vega_to_jpeg(
     vg_spec: PyObject,
     scale: Option<f32>,
     quality: Option<u8>,
     allowed_base_urls: Option<Vec<String>>,
+    format_locale: Option<PyObject>,
+    time_format_locale: Option<PyObject>,
 ) -> PyResult<PyObject> {
     let vg_spec = parse_json_spec(vg_spec)?;
+    let format_locale = parse_option_format_locale(format_locale)?;
+    let time_format_locale = parse_option_time_format_locale(time_format_locale)?;
 
     let mut converter = VL_CONVERTER
         .lock()
@@ -403,7 +481,11 @@ fn vega_to_jpeg(
 
     let jpeg_data = match PYTHON_RUNTIME.block_on(converter.vega_to_jpeg(
         vg_spec,
-        VgOpts { allowed_base_urls },
+        VgOpts {
+            allowed_base_urls,
+            format_locale,
+            time_format_locale,
+        },
         scale,
         quality,
     )) {
@@ -435,11 +517,13 @@ fn vega_to_jpeg(
 ///     show_warnings (bool | None): Whether to print Vega-Lite compilation warnings (default false)
 ///     allowed_base_urls (list of str): List of allowed base URLs for external
 ///                                      data requests. Default allows any base URL
+///     format_locale (str | dict): d3-format locale name or dictionary
+///     time_format_locale (str | dict): d3-time-format locale name or dictionary
 /// Returns:
 ///     bytes: JPEG image data
 #[pyfunction]
 #[pyo3(
-    text_signature = "(vl_spec, vl_version, scale, quality, config, theme, show_warnings, allowed_base_urls)"
+    text_signature = "(vl_spec, vl_version, scale, quality, config, theme, show_warnings, allowed_base_urls, format_locale, time_format_locale)"
 )]
 #[allow(clippy::too_many_arguments)]
 fn vegalite_to_jpeg(
@@ -451,6 +535,8 @@ fn vegalite_to_jpeg(
     theme: Option<String>,
     show_warnings: Option<bool>,
     allowed_base_urls: Option<Vec<String>>,
+    format_locale: Option<PyObject>,
+    time_format_locale: Option<PyObject>,
 ) -> PyResult<PyObject> {
     let vl_version = if let Some(vl_version) = vl_version {
         VlVersion::from_str(vl_version)?
@@ -459,6 +545,8 @@ fn vegalite_to_jpeg(
     };
     let vl_spec = parse_json_spec(vl_spec)?;
     let config = config.and_then(|c| parse_json_spec(c).ok());
+    let format_locale = parse_option_format_locale(format_locale)?;
+    let time_format_locale = parse_option_time_format_locale(time_format_locale)?;
 
     let mut converter = VL_CONVERTER
         .lock()
@@ -472,6 +560,8 @@ fn vegalite_to_jpeg(
             theme,
             show_warnings: show_warnings.unwrap_or(false),
             allowed_base_urls,
+            format_locale,
+            time_format_locale,
         },
         scale,
         quality,
@@ -497,16 +587,22 @@ fn vegalite_to_jpeg(
 ///     scale (float): Image scale factor (default 1.0)
 ///     allowed_base_urls (list of str): List of allowed base URLs for external
 ///                                      data requests. Default allows any base URL
+///     format_locale (str | dict): d3-format locale name or dictionary
+///     time_format_locale (str | dict): d3-time-format locale name or dictionary
 /// Returns:
 ///     bytes: PDF file bytes
 #[pyfunction]
-#[pyo3(text_signature = "(vg_spec, scale, allowed_base_urls)")]
+#[pyo3(text_signature = "(vg_spec, scale, allowed_base_urls, format_locale, time_format_locale)")]
 fn vega_to_pdf(
     vg_spec: PyObject,
     scale: Option<f32>,
     allowed_base_urls: Option<Vec<String>>,
+    format_locale: Option<PyObject>,
+    time_format_locale: Option<PyObject>,
 ) -> PyResult<PyObject> {
     let vg_spec = parse_json_spec(vg_spec)?;
+    let format_locale = parse_option_format_locale(format_locale)?;
+    let time_format_locale = parse_option_time_format_locale(time_format_locale)?;
 
     let mut converter = VL_CONVERTER
         .lock()
@@ -514,7 +610,11 @@ fn vega_to_pdf(
 
     let pdf_bytes = match PYTHON_RUNTIME.block_on(converter.vega_to_pdf(
         vg_spec,
-        VgOpts { allowed_base_urls },
+        VgOpts {
+            allowed_base_urls,
+            format_locale,
+            time_format_locale,
+        },
         scale,
     )) {
         Ok(vega_spec) => vega_spec,
@@ -542,10 +642,15 @@ fn vega_to_pdf(
 ///     theme (str | None): Named theme (e.g. "dark") to apply during conversion
 ///     allowed_base_urls (list of str): List of allowed base URLs for external
 ///                                      data requests. Default allows any base URL
+///     format_locale (str | dict): d3-format locale name or dictionary
+///     time_format_locale (str | dict): d3-time-format locale name or dictionary
 /// Returns:
 ///     bytes: PDF image data
+#[allow(clippy::too_many_arguments)]
 #[pyfunction]
-#[pyo3(text_signature = "(vl_spec, vl_version, scale, config, theme, allowed_base_urls)")]
+#[pyo3(
+    text_signature = "(vl_spec, vl_version, scale, config, theme, allowed_base_urls, format_locale, time_format_locale)"
+)]
 fn vegalite_to_pdf(
     vl_spec: PyObject,
     vl_version: Option<&str>,
@@ -554,6 +659,8 @@ fn vegalite_to_pdf(
     theme: Option<String>,
     show_warnings: Option<bool>,
     allowed_base_urls: Option<Vec<String>>,
+    format_locale: Option<PyObject>,
+    time_format_locale: Option<PyObject>,
 ) -> PyResult<PyObject> {
     let vl_version = if let Some(vl_version) = vl_version {
         VlVersion::from_str(vl_version)?
@@ -562,6 +669,8 @@ fn vegalite_to_pdf(
     };
     let vl_spec = parse_json_spec(vl_spec)?;
     let config = config.and_then(|c| parse_json_spec(c).ok());
+    let format_locale = parse_option_format_locale(format_locale)?;
+    let time_format_locale = parse_option_time_format_locale(time_format_locale)?;
 
     let mut converter = VL_CONVERTER
         .lock()
@@ -575,6 +684,8 @@ fn vegalite_to_pdf(
             theme,
             show_warnings: show_warnings.unwrap_or(false),
             allowed_base_urls,
+            format_locale,
+            time_format_locale,
         },
         scale,
     )) {
@@ -637,17 +748,22 @@ fn vega_to_url(vg_spec: PyObject, fullscreen: Option<bool>) -> PyResult<String>
 ///         If False (default), HTML file will load dependencies from only CDN
 ///     config (dict | None): Chart configuration object to apply during conversion
 ///     theme (str | None): Named theme (e.g. "dark") to apply during conversion
-///
+///     format_locale (str | dict): d3-format locale name or dictionary
+///     time_format_locale (str | dict): d3-time-format locale name or dictionary
 /// Returns:
 ///     string: HTML document
 #[pyfunction]
-#[pyo3(text_signature = "(vl_spec, vl_version, bundle, config, theme)")]
+#[pyo3(
+    text_signature = "(vl_spec, vl_version, bundle, config, theme, format_locale, time_format_locale)"
+)]
 fn vegalite_to_html(
     vl_spec: PyObject,
     vl_version: Option<&str>,
     bundle: Option<bool>,
     config: Option<PyObject>,
     theme: Option<String>,
+    format_locale: Option<PyObject>,
+    time_format_locale: Option<PyObject>,
 ) -> PyResult<String> {
     let vl_version = if let Some(vl_version) = vl_version {
         VlVersion::from_str(vl_version)?
@@ -656,6 +772,8 @@ fn vegalite_to_html(
     };
     let vl_spec = parse_json_spec(vl_spec)?;
     let config = config.and_then(|c| parse_json_spec(c).ok());
+    let format_locale = parse_option_format_locale(format_locale)?;
+    let time_format_locale = parse_option_time_format_locale(time_format_locale)?;
 
     let mut converter = VL_CONVERTER
         .lock()
@@ -669,6 +787,8 @@ fn vegalite_to_html(
             theme,
             show_warnings: false,
             allowed_base_urls: None,
+            format_locale,
+            time_format_locale,
         },
         bundle.unwrap_or(false),
     ))?)
@@ -680,17 +800,34 @@ fn vegalite_to_html(
 ///     vg_spec (str | dict): Vega JSON specification string or dict
 ///     bundle (bool): If True, bundle all dependencies in HTML file
 ///         If False (default), HTML file will load dependencies from only CDN
-///
+///     format_locale (str | dict): d3-format locale name or dictionary
+///     time_format_locale (str | dict): d3-time-format locale name or dictionary
 /// Returns:
 ///     string: HTML document
 #[pyfunction]
-#[pyo3(text_signature = "(vg_spec, bundle)")]
-fn vega_to_html(vg_spec: PyObject, bundle: Option<bool>) -> PyResult<String> {
+#[pyo3(text_signature = "(vg_spec, bundle, format_locale, time_format_locale)")]
+fn vega_to_html(
+    vg_spec: PyObject,
+    bundle: Option<bool>,
+    format_locale: Option<PyObject>,
+    time_format_locale: Option<PyObject>,
+) -> PyResult<String> {
     let vg_spec = parse_json_spec(vg_spec)?;
+    let format_locale = parse_option_format_locale(format_locale)?;
+    let time_format_locale = parse_option_time_format_locale(time_format_locale)?;
+
     let mut converter = VL_CONVERTER
         .lock()
         .expect("Failed to acquire lock on Vega-Lite converter");
-    Ok(PYTHON_RUNTIME.block_on(converter.vega_to_html(vg_spec, bundle.unwrap_or(false)))?)
+    Ok(PYTHON_RUNTIME.block_on(converter.vega_to_html(
+        vg_spec,
+        VgOpts {
+            allowed_base_urls: None,
+            format_locale,
+            time_format_locale,
+        },
+        bundle.unwrap_or(false),
+    ))?)
 }
 
 /// Convert an SVG image string to PNG image data
@@ -768,6 +905,75 @@ fn parse_json_spec(vl_spec: PyObject) -> PyResult<serde_json::Value> {
     })
 }
 
+/// Helper function to parse an input Python string or dict as a FormatLocale
+fn parse_format_locale(v: PyObject) -> PyResult<FormatLocale> {
+    Python::with_gil(|py| -> PyResult<FormatLocale> {
+        if let Ok(name) = v.extract::<&str>(py) {
+            let format_locale = FormatLocale::Name(name.to_string());
+            if format_locale.as_object().is_err() {
+                Err(PyValueError::new_err(
+                    format!("Invalid format_locale name: {name}\nSee https://github.com/d3/d3-format/tree/main/locale for available names")
+                ))
+            } else {
+                Ok(format_locale)
+            }
+        } else if let Ok(obj) = v.downcast::<PyDict>(py) {
+            match depythonize(obj) {
+                Ok(obj) => Ok(FormatLocale::Object(obj)),
+                Err(err) => Err(PyValueError::new_err(format!(
+                    "Failed to parse format_locale dict as JSON: {}",
+                    err
+                ))),
+            }
+        } else {
+            Err(PyValueError::new_err(
+                "format_locale must be a string or dict",
+            ))
+        }
+    })
+}
+fn parse_option_format_locale(v: Option<PyObject>) -> PyResult<Option<FormatLocale>> {
+    match v {
+        None => Ok(None),
+        Some(v) => Ok(Some(parse_format_locale(v)?)),
+    }
+}
+
+/// Helper function to parse an input Python string or dict as a TimeFormatLocale
+fn parse_time_format_locale(v: PyObject) -> PyResult<TimeFormatLocale> {
+    Python::with_gil(|py| -> PyResult<TimeFormatLocale> {
+        if let Ok(name) = v.extract::<&str>(py) {
+            let time_format_locale = TimeFormatLocale::Name(name.to_string());
+            if time_format_locale.as_object().is_err() {
+                Err(PyValueError::new_err(
+                    format!("Invalid time_format_locale name: {name}\nSee https://github.com/d3/d3-time-format/tree/main/locale for available names")
+                ))
+            } else {
+                Ok(time_format_locale)
+            }
+        } else if let Ok(obj) = v.downcast::<PyDict>(py) {
+            match depythonize(obj) {
+                Ok(obj) => Ok(TimeFormatLocale::Object(obj)),
+                Err(err) => Err(PyValueError::new_err(format!(
+                    "Failed to parse time_format_locale dict as JSON: {}",
+                    err
+                ))),
+            }
+        } else {
+            Err(PyValueError::new_err(
+                "time_format_locale must be a string or dict",
+            ))
+        }
+    })
+}
+
+fn parse_option_time_format_locale(v: Option<PyObject>) -> PyResult<Option<TimeFormatLocale>> {
+    match v {
+        None => Ok(None),
+        Some(v) => Ok(Some(parse_time_format_locale(v)?)),
+    }
+}
+
 /// Register a directory of fonts for use in subsequent conversions
 ///
 /// Args:
@@ -831,6 +1037,64 @@ fn get_themes() -> PyResult<PyObject> {
     })
 }
 
+/// Get the d3-format locale dict for a named locale
+///
+/// See https://github.com/d3/d3-format/tree/main/locale for available names
+///
+/// Args:
+///     name (str): d3-format locale name (e.g. 'it-IT')
+///
+/// Returns:
+///     dict: d3-format locale dict
+#[pyfunction]
+#[pyo3(text_signature = "(name)")]
+fn get_format_locale(name: &str) -> PyResult<PyObject> {
+    match FORMATE_LOCALE_MAP.get(name) {
+        None => {
+            Err(PyValueError::new_err(format!(
+                "Invalid format locale name: {name}\nSee https://github.com/d3/d3-format/tree/main/locale for available names"
+            )))
+        }
+        Some(locale) => {
+            let locale: serde_json::Value = serde_json::from_str(locale).expect(
+                "Failed to parse internal format locale as JSON"
+            );
+            Python::with_gil(|py| -> PyResult<PyObject> {
+                pythonize(py, &locale).map_err(|err| PyValueError::new_err(err.to_string()))
+            })
+        }
+    }
+}
+
+/// Get the d3-time-format locale dict for a named locale
+///
+/// See https://github.com/d3/d3-time-format/tree/main/locale for available names
+///
+/// Args:
+///     name (str): d3-time-format locale name (e.g. 'it-IT')
+///
+/// Returns:
+///     dict: d3-time-format locale dict
+#[pyfunction]
+#[pyo3(text_signature = "(name)")]
+fn get_time_format_locale(name: &str) -> PyResult<PyObject> {
+    match TIME_FORMATE_LOCALE_MAP.get(name) {
+        None => {
+            Err(PyValueError::new_err(format!(
+                "Invalid time format locale name: {name}\nSee https://github.com/d3/d3-time-format/tree/main/locale for available names"
+            )))
+        }
+        Some(locale) => {
+            let locale: serde_json::Value = serde_json::from_str(locale).expect(
+                "Failed to parse internal time format locale as JSON"
+            );
+            Python::with_gil(|py| -> PyResult<PyObject> {
+                pythonize(py, &locale).map_err(|err| PyValueError::new_err(err.to_string()))
+            })
+        }
+    }
+}
+
 /// Create a JavaScript bundle containing the Vega Embed, Vega-Lite, and Vega libraries
 ///
 /// Optionally, a JavaScript snippet may be provided that references Vega Embed
@@ -891,6 +1155,8 @@ fn vl_convert(_py: Python, m: &PyModule) -> PyResult<()> {
     m.add_function(wrap_pyfunction!(register_font_directory, m)?)?;
     m.add_function(wrap_pyfunction!(get_local_tz, m)?)?;
     m.add_function(wrap_pyfunction!(get_themes, m)?)?;
+    m.add_function(wrap_pyfunction!(get_format_locale, m)?)?;
+    m.add_function(wrap_pyfunction!(get_time_format_locale, m)?)?;
     m.add_function(wrap_pyfunction!(javascript_bundle, m)?)?;
     m.add("__version__", env!("CARGO_PKG_VERSION"))?;
     Ok(())
